@@ -1,6 +1,7 @@
 import calendar
 import json
 import os
+import re
 import shutil
 import time
 import uuid
@@ -11,11 +12,9 @@ from confluent_kafka import Producer
 from mobio.libs.Singleton import Singleton
 from mobio.libs.caching import LruCache
 
-from .custom_mimetypes import CustomMimetypes
-from .config import ConsumerTopic
-from .config import MobioEnvironment
-from .config import StoreCacheType, Cache
+from .config import ConsumerTopic, MobioEnvironment, StoreCacheType, Cache
 from .constant import DirSaveFile, FieldConstantResponse, CONSTANT_MAP_FORMAT_FILE
+from .custom_mimetypes import CustomMimetypes
 from .dir import APP_TMP_DATA_DIR, STATIC_DATA_DIR
 
 
@@ -24,6 +23,7 @@ class MobioMediaSDK(object):
     lru_cache = None
     DEFAULT_REQUEST_TIMEOUT_SECONDS = 15
     LIST_VERSION_VALID = ["api/v1.0"]
+    pattern_domain = r"^(?:http:\/\/|www\.|https:\/\/)([^\/]+)/static/"
 
     def __init__(self):
         self.folder_static = 'static'
@@ -72,16 +72,16 @@ class MobioMediaSDK(object):
     @staticmethod
     def valid_input_upload(file_path, file_data, merchant_id, expire=None):
         if not merchant_id:
-            raise Exception("merchant_id require")
+            raise Exception("[ERROR] merchant_id require")
         if not file_path and not file_data:
-            raise Exception("Need to pass 1 of 2 parameters file_path or file_data")
+            raise Exception("[ERROR] Need to pass 1 of 2 parameters file_path or file_data")
         if file_path and not os.path.isfile(file_path):
-            raise Exception("file_path: {} not exist.".format(file_path))
+            raise Exception("[ERROR] file_path: {} not exist.".format(file_path))
         if expire:
             try:
                 expire = datetime.strptime(expire, "%Y-%m-%dT%H:%M:%SZ")
             except Exception as ex:
-                raise Exception("format expire: {} error: {}".format(expire, ex))
+                raise Exception("[ERROR] format expire: {} error: {}".format(expire, ex))
 
     @staticmethod
     def get_file_name(file_path, file_data):
@@ -170,9 +170,6 @@ class MobioMediaSDK(object):
             "do_not_delete": do_not_delete
         }
 
-        # message_data = Message(message=data_send_producer)
-        # KafkaUtil().produce(topic=ConsumerTopic.TOPIC_SAVE_INFO_MEDIA_SDK, message=message_data)
-        print("upload_without_kafka()::send message to topic:: %s" % (time.time() - time_start))
         self.send_message_to_topic(topic=ConsumerTopic.TOPIC_SAVE_INFO_MEDIA_SDK, data=json.dumps(data_send_producer))
         print("upload_without_kafka()::send message to topic:: %s" % (time.time() - time_start))
         return {
@@ -292,45 +289,29 @@ class MobioMediaSDK(object):
         all_format_desired = CONSTANT_MAP_FORMAT_FILE.get(desired_format)
         if (not all_format_desired) or (mimetype_str not in all_format_desired):
             extension = CustomMimetypes().mimetypes.guess_extension(mimetype_str)
-            raise Exception("File định dạng {}, không đúng định dạng mong muốn là {}".format(extension, desired_format))
+            raise Exception(
+                "[ERROR] File định dạng {}, không đúng định dạng mong muốn là {}".format(extension, desired_format))
 
-    def get_local_path_by_url(
+    def get_path_by_url(
             self,
-            url,
-            merchant_id
+            url
     ):
-        host_by_merchant_id = self._get_host_by_merchant_id(merchant_id=merchant_id)
-        host = os.path.join(host_by_merchant_id, self.folder_static)
-        url_without_host = url.replace(host, "")
-        url_without_host = url_without_host.split("/")
-        url_without_host = [url for url in url_without_host if url]
-        filename = url_without_host[-1]
-        local_path = None
-        if len(url_without_host) == 1:
-            local_path, filename = self.create_dir_save_file(
-                folder=STATIC_DATA_DIR,
-                merchant_id=None,
-                type_media=None,
-                filename=filename
-            )
-
-        if len(url_without_host) == 2:
-            local_path, filename = self.create_dir_save_file(
-                folder=STATIC_DATA_DIR,
-                merchant_id=merchant_id,
-                type_media=None,
-                filename=filename
-            )
-
-        if len(url_without_host) == 3:
-            local_path, filename = self.create_dir_save_file(
-                folder=STATIC_DATA_DIR,
-                merchant_id=merchant_id,
-                type_media=url_without_host[1],
-                filename=filename
-            )
+        if not url:
+            raise ValueError("[ERROR] URL not none")
+        try:
+            local_path = re.sub(self.pattern_domain, STATIC_DATA_DIR + "/", url)
+        except Exception as ex:
+            print("[ERROR] get local_path_file error %s " % ex)
+            raise Exception("url %s not found" % url)
+        if not os.path.isfile(local_path):
+            raise Exception("[ERROR] local_path :: %s not exists" % local_path)
         return local_path
 
+    def get_binary_by_url(self, url):
+        local_path = self.get_local_path_by_url(url)
+        with open(local_path, "r") as f:
+            return f.read()
+
     def create_filepath(
             self,
             merchant_id: str,
@@ -404,7 +385,7 @@ class MobioMediaSDK(object):
             mimetype_str = magic_init.from_file(file_path)
         else:
             mimetype_str = file_data.mimetype if file_data.mimetype else file_data.content_type
-        print("mimetype_str::mimetype_str")
+        print("mimetype_str:: %s" % mimetype_str)
         return mimetype_str
 
     def override_file(
@@ -455,7 +436,7 @@ class MobioMediaSDK(object):
             type_delete=None
     ):
         if not urls:
-            print("urls empty")
+            print("[ERROR] urls empty")
             return None
 
         data_send_producer = {
@@ -477,3 +458,4 @@ class MobioMediaSDK(object):
         self.instance.poll(0)
         print("topic: {}, message: {}".format(topic, data))
         self.instance.flush()
+
